@@ -2,6 +2,7 @@ import copy
 import logging
 from collections.abc import MutableMapping
 from collections.abc import Sequence
+from enum import Enum
 from typing import Callable
 from typing import Iterable
 from typing import List
@@ -132,7 +133,12 @@ class SklearnInstrumentor:
 
     @classmethod
     def _get_instrumentation_attribute_name(cls, method_name: str):
-        return f"_skli_{method_name}"
+        prefix = cls._get_instrumentation_attribute_prefix()
+        return f"{prefix}{method_name}"
+
+    @classmethod
+    def _get_instrumentation_attribute_prefix(cls):
+        return "_skli_"
 
     # region instrumentation estimator
     def instrument_estimator(
@@ -169,7 +175,10 @@ class SklearnInstrumentor:
             )
 
     def _instrument_recursively(self, obj: object, instrument_kwargs=None):
-        if isinstance(obj, (*self.exclude, str, np.ndarray)):
+        if isinstance(obj, tuple(self.exclude)):
+            return
+
+        if isinstance(obj, (str, np.ndarray, Enum)):
             return
 
         if isinstance(obj, BaseEstimator):
@@ -178,7 +187,9 @@ class SklearnInstrumentor:
             )
 
         if hasattr(obj, "__dict__"):
-            for v in obj.__dict__.values():
+            for k, v in obj.__dict__.items():
+                if k.startswith(self._get_instrumentation_attribute_prefix()):
+                    continue
                 self._instrument_recursively(obj=v, instrument_kwargs=instrument_kwargs)
         elif isinstance(obj, MutableMapping):
             for v in obj.values():
@@ -250,14 +261,19 @@ class SklearnInstrumentor:
             self._uninstrument_estimator(estimator=estimator, full=full)
 
     def _uninstrument_recursively(self, obj: object, full: bool = False):
-        if isinstance(obj, (*self.exclude, str, np.ndarray)):
+        if isinstance(obj, tuple(self.exclude)):
+            return
+
+        if isinstance(obj, (str, np.ndarray, Enum)):
             return
 
         if isinstance(obj, BaseEstimator):
             self._uninstrument_estimator(estimator=obj, full=full)
 
         if hasattr(obj, "__dict__"):
-            for v in obj.__dict__.values():
+            for k, v in obj.__dict__.items():
+                if k.startswith(self._get_instrumentation_attribute_prefix()):
+                    continue
                 self._uninstrument_recursively(obj=v, full=full)
         elif isinstance(obj, MutableMapping):
             for v in obj.values():
@@ -363,7 +379,10 @@ class SklearnInstrumentor:
 
     def _get_estimator_classes(self, obj):
         classes = set()
-        if isinstance(obj, (*self.exclude, str, np.ndarray)):
+        if isinstance(obj, tuple(self.exclude)):
+            return classes
+
+        if isinstance(obj, (str, np.ndarray, Enum)):
             return classes
 
         if isinstance(obj, BaseEstimator):
